\NeedsTeXFormat{LaTeX2e}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{scrbook}}
\ProcessOptions\relax
\LoadClass{scrbook}
\ProvidesClass{skript}

\RequirePackage{tikz}
\usetikzlibrary{babel}
\RequirePackage{tikz-cd}
\tikzcdset{arrow style=tikz, diagrams={>=stealth}}

\RequirePackage{ifxetex,ifluatex}
\newif\ifxetexorluatex
\ifxetex
  \xetexorluatextrue
\else
  \ifluatex
    \xetexorluatextrue
  \else
    \xetexorluatexfalse
  \fi
\fi

\RequirePackage{scrlayer-scrpage}

\RequirePackage{gitinfo}

\RequirePackage{mathtools}
\RequirePackage{amsmath,  amssymb}

\ifxetexorluatex
    \RequirePackage[babelshorthands]{polyglossia}
    \setdefaultlanguage{german}
    \RequirePackage{fontspec}
    \defaultfontfeatures{Mapping=tex-text}
    \RequirePackage{empheq}
    \setmainfont{Libertinus Serif}
    \RequirePackage[warnings-off={mathtools-colon,mathtools-overbracket}]{unicode-math}
    \setmathfont[AutoFakeBold]{Libertinus Math}
    \setmathfont[AutoFakeBold,range={\rightarrow,\leftarrow,\rightharpoonup,\rightharpoondown,\leftharpoondown,\leftharpoonup}]{texgyretermes-math.otf}
    \setmathfont[AutoFakeBold,range={\Vert,\lbrace,\rbrace,\vert}]{xits-math.otf}
    \setmathfont[AutoFakeBold,range={\BbbQ,\BbbN,\BbbR,\BbbC,\BbbZ,\mathbb,\int}]{XITS Math}
    % \setmathfont[range={\mathcal, \mathbfcal}]{tgpagella-math.otf}
%    \setmathfont[range={}]{Libertinus Math}
    % \setmathfont{latinmodern-math.otf}[range={cal,bfcal}]
\else
    \RequirePackage[ngerman]{babel}
    \RequirePackage[utf8]{inputenc}
    \RequirePackage{uniinput}
    \RequirePackage[sb,tt=false]{libertine}
    \RequirePackage[libertine]{newtxmath}
    \RequirePackage[cal=zapfc,bb=boondox]{mathalfa}
    \RequirePackage[T1]{fontenc}
    \def\lAngle{\langle\langle}
    \def\rAngle{\rangle\rangle}
\fi
% fonts
\setkomafont{disposition}{\rmfamily}

\setkomafont{chapter}{\Huge}
\addtokomafont{chapterprefix}{\raggedleft}
\renewcommand*{\chapterformat}{%
    \hrulefill\enskip\mbox{\scalebox{3}{\thechapter\autodot}}\vspace{-0.6\baselineskip}}
\usepackage{etoolbox}
\newcommand\chaptertopline{\smash{\raisebox{-3.5\baselineskip}{\rule{\textwidth}{.4pt}}}}
\makeatletter
\preto{\@@makeschapterhead}{\chaptertopline}
\preto{\@@makechapterhead}{\ifunnumbered{chapter}{\chaptertopline}{}}
\makeatother
\preto{\chapterheadendvskip}{\noindent\hrulefill\par}
\RedeclareSectionCommand[
  beforeskip=12ex,
  afterskip=2\baselineskip]{chapter}

% fonts
\RequirePackage{setspace}
\setstretch{1.1}
% \setlength\parskip{4pt}
% \setlength\parindent{0pt}

\RequirePackage[amsmath, thmmarks, framed]{ntheorem}
\RequirePackage[framemethod=tikz]{mdframed}

\RequirePackage[unicode,colorlinks,bookmarksopen=true]{hyperref}
\RequirePackage[capitalise, nameinlink]{cleveref}

\pagestyle{scrheadings}
\clearscrheadfoot
\ohead{\headmark}
\cfoot{\pagemark}
\ifoot{\tiny Revision\gitVtags: \gitAbbrevHash{} (\gitAuthorDate)}
\automark{section}

\RequirePackage[
    backend=biber,
    style=alphabetic,
    giveninits,
    url=true,
    ]{biblatex}

\def\nikeswoosh{\begin{tikzpicture}[y=0.80pt, x=0.80pt, yscale=-0.100000, xscale=0.100000, inner sep=0pt, outer sep=0pt]
\fill[black] (159.2300,431.9660) .. controls (153.3900,431.7340) and
  (148.6120,430.1360) .. (144.8760,427.1680) .. controls (144.1630,426.6010) and
  (142.4640,424.9010) .. (141.8940,424.1840) .. controls (140.3790,422.2790) and
  (139.3490,420.4250) .. (138.6620,418.3680) .. controls (136.5480,412.0360) and
  (137.6360,403.7270) .. (141.7740,394.6080) .. controls (145.3170,386.8010) and
  (150.7840,379.0580) .. (160.3220,368.3340) .. controls (161.7270,366.7560) and
  (165.9110,362.1410) .. (165.9380,362.1410) .. controls (165.9480,362.1410) and
  (165.7200,362.5360) .. (165.4330,363.0170) .. controls (162.9530,367.1710) and
  (160.8310,372.0640) .. (159.6750,376.3000) .. controls (157.8180,383.0970) and
  (158.0420,388.9300) .. (160.3310,393.4530) .. controls (161.9100,396.5690) and
  (164.6170,399.2680) .. (167.6610,400.7600) .. controls (172.9900,403.3710) and
  (180.7920,403.5870) .. (190.3200,401.3920) .. controls (190.9760,401.2400) and
  (223.4820,392.6110) .. (262.5560,382.2160) .. controls (301.6300,371.8200) and
  (333.6050,363.3210) .. (333.6100,363.3280) .. controls (333.6210,363.3370) and
  (242.8300,402.1870) .. (195.6990,422.3420) .. controls (188.2350,425.5330) and
  (186.2390,426.3390) .. (182.7300,427.5710) .. controls (173.7600,430.7210) and
  (165.7250,432.2240) .. (159.2300,431.9660) -- cycle;
\end{tikzpicture}}

\usepackage{enumitem}
\setenumerate{label=(\alph*)}

\makeatletter
\makeatletter 
 \newtheoremstyle{mychange}%
  {\item[\hskip\labelsep \theorem@headerfont ##2\hskip 0.3em\ ##1\theorem@separator]}%
  {\item[\hskip\labelsep \theorem@headerfont ##2\hskip 0.3em\ ##1\ (##3)\theorem@separator]}
 \newtheoremstyle{nonumbermychange}%
  {\item[\hskip\labelsep \theorem@headerfont ##1\theorem@separator]}%
  {\item[\hskip\labelsep \theorem@headerfont ##1\ (##3)\theorem@separator]}
\makeatother
\DeclareDocumentCommand\newmdtheoremenv{s O{} m o m o }{%
\IfBooleanTF{#1}{%
   \newtheorem*{#3}{#5}%
 }{%
 \ifboolexpr{ test {\IfNoValueTF {#4}} and test {\IfNoValueTF {#6}} }%
    {\newtheorem{#3}{#5}}{%
     \IfValueTF{#4}{\newtheorem{#3}[#4]{#5}}{}%
     \IfValueTF{#6}{\newtheorem{#3}{#5}[#6]}{}%
    }
  }%
  \BeforeBeginEnvironment{#3}{%
     \begin{mdframed}[#2]}%
  \AfterEndEnvironment{#3}{%
     \end{mdframed}}%
}
\newcounter{defsatzusw}
\def\newthm#1#2{
    \newmdtheoremenv[ntheorem,
    leftmargin=1em,
    linewidth=6pt,
    % linecolor=myurlcolor!20,
    linecolor=black!30,
    leftline=true, rightline=false, bottomline=false, topline=false,
    innerleftmargin=1em,
    ]{#1}[defsatzusw]{#2}
    \newmdtheoremenv*[ntheorem,
    leftmargin=1em,
    linewidth=6pt,
    % linecolor=myurlcolor!20,
    linecolor=black!20,
    leftline=true, rightline=false, bottomline=false, topline=false,
    innerleftmargin=1em,
    ]{#1-nn}{#2}
}
\def\newdef#1#2{\newtheorem{#1}[defsatzusw]{#2}\newtheorem*{#1-nn}{#2}}
\theoremseparator{.}
\numberwithin{defsatzusw}{section}
% kursive schrift
\theorembodyfont{\normalfont}
\theoremstyle{mychange}
\newthm{satz}{Satz}
\newthm{lemma}{Lemma}
\newthm{korollar}{Korollar}
\newthm{folgerung}{Folgerung}
\newthm{hilfssatz}{Hilfssatz}
\newthm{proposition}{Proposition}
% aufrechte schrift
\theorembodyfont{\normalfont}
\newthm{bezeichnung}{Bezeichnung}
\newthm{bezeichnungen}{Bezeichnungen}
\newthm{voraussetzung}{Voraussetzung}
\newthm{voraussetzungen}{Voraussetzungen}
\newdef{bemerkung}{Bemerkung}
\newdef{bemerkungen}{Bemerkungen}
\newdef{definition}{Definition}
\newdef{warnung}{Warnung}
\newdef{frage}{Frage}
\newdef{erinnerung}{Erinnerung}
\newdef{beispiel}{Beispiel}
\newdef{beispiele}{Beispiele}
\newdef{problem}{Problem}

\theoremstyle{nonumberplain}
\theoremheaderfont{\itshape}
\theorembodyfont{\normalfont}
\theoremseparator{.}
% \theoremsymbol{\scalebox{0.8}{\ensuremath{\blacksquare}}}
\theoremsymbol{\nolinebreak[1]\hspace*{.5em plus 1fill}\scalebox{0.8}{\ensuremath{\blacksquare}}}
\newtheorem{proof}{Beweis}
\newtheorem{beweis}{Beweis}
\theoremsymbol{\nolinebreak[1]\hspace*{.5em plus 1fill}\scalebox{0.8}{\ensuremath{\nikeswoosh}}}
\newtheorem{noproof}{Beweis}

\renewcommand{\thesection}{\arabic{section}}
\renewcommand\sectionformat{\S \thesection\autodot \hspace{1ex}}

\endinput